@@ -219,7 +219,7 @@ sub get_default_config_settings
         modules_dir => '',         # set in get_cmdline_options
         cchannels => '',           # set in get_cmdline_options
 
-        version => "0.68",
+        version => "0.70",
     };
 
     # This enables us to use the search_path in other modules
@@ -551,7 +551,7 @@ sub parse_channels
             my $hits = 0;
             foreach ( @{ $self->{chans} }) {
                 my $chan = (keys %{ $_ })[0];
-                if ($channel =~ m/^$chan$/i) {
+                if (lc($channel) eq lc($chan)) {
                     push @chanlist, $_;
                     $hits++;
                 }
