@@ -414,11 +414,11 @@ sub _parse_file
                     }
 
                     # require 2 chars (catches C++), nick must not end in [+=-]
-                    if ($saying =~ /^(\S*\w\S*\w\S*(?<![+=-]))(\+\+|==|--)$/o) {
+                    if ($saying =~ /^(\S+[^\s+=-])(\+\+|==|--)$/) {
                         my $thing = lc $1;
                         my $k = $2 eq "++" ? 1 : ($2 eq "==" ? 0 : -1);
                         $stats->{karma}{$thing}{$nick} = $k
-                            if !is_ignored($thing) and $thing ne lc($nick);
+                            if $thing =~ /\w\W*?\w/ and !is_ignored($thing) and $thing ne lc($nick);
                     }
 
                     # Find URLs
@@ -588,6 +588,7 @@ sub _parse_file
     my $wordcount = sqrt(sqrt(keys %{$stats->{wordcounts}})); # remove less frequent words
     foreach my $word (keys %{$stats->{wordcounts}}) {
         if ($stats->{wordcounts}->{$word} < $wordcount) {
+            next if defined $stats->{chartcounts}{$word};
             delete $stats->{wordcounts}->{$word};
             delete $stats->{wordnicks}->{$word};
             delete $stats->{word_upcase}->{$word};
@@ -634,6 +635,9 @@ sub _parse_words
     my $tod = int($hour/6);
 
     foreach my $word (split(/[\s,!?.:;)(\"]+/o, $saying)) {
+        # ignore if $word is empty
+        next if $word eq "";
+
         $stats->{words}{$nick}++;
         $stats->{word_times}{$nick}[$tod]++;
         # remove uninteresting words
@@ -664,6 +668,9 @@ sub _charts
     $Song =~ s/\.(mp3|ogg|wma)//ig;
     $Song =~ s/\[[^\] ]*\]/ /g; # strip stuff in brackets [44kbps]
     $Song =~ s/^ *[^\w]* *| *[^\w]* *$//g;
+
+    return unless length $Song;
+    
     my $song = lc $Song;
     $stats->{word_upcase}{$song} = $Song;
     $stats->{chartcounts}{$song}++;
